@@ -23,6 +23,7 @@ class PullFailed(GitException):
 
 class Git:
     _GIT = 'git'
+    _GIT_ENCODING = 'utf-8'
 
     _APP_EMAIL = f'{APP}@localhost'
     _ARBITRARY_FIXED_DATETIME = '2005-12-21T00:00:00+00:00'  # release date of Git 1.0.0
@@ -35,9 +36,8 @@ class Git:
         'GIT_COMMITTER_NAME': APP,
     }
 
-    def __init__(self, messenger, ask, pretend, verbose, work_dir=None):
+    def __init__(self, messenger, pretend, verbose, work_dir=None):
         self._messenger = messenger
-        self._ask = ask
         self._verbose = verbose
         self._pretend = pretend
         self._working_directory = work_dir
@@ -54,21 +54,21 @@ class Git:
 
     @classmethod
     def _output_bytes_to_lines(cls, output_bytes) -> List[str]:
-        text = output_bytes.decode('utf-8').rstrip()
+        text = output_bytes.decode(cls._GIT_ENCODING).rstrip()
         if not text:  # protect against this: ''.split('\n') -> ['']
             return []
         return text.split('\n')
 
     def extract_git_config(self):
-        argv = [self._GIT, 'config', '--list']
+        argv = [self._GIT, 'config', '--list', '--null']
         output_bytes = self._subprocess_check_output(argv, is_write=False)
-        config_lines = self._output_bytes_to_lines(output_bytes)
+        key_newline_value_list = [chunk.decode(self._GIT_ENCODING)
+                                  for chunk in output_bytes.split(b'\0')]
         git_config = OrderedDict()
-        for line in config_lines:
-            equal_sign_index = line.index('=')
-            if equal_sign_index < 1:
+        for key_newline_value in key_newline_value_list:
+            if not key_newline_value:
                 continue
-            key, value = line[:equal_sign_index], line[equal_sign_index + 1:]
+            key, value = key_newline_value.split('\n', 1)
             git_config[key] = value
         return git_config
 
